Index: chrome/browser/ui/views/location_bar/location_bar_view.h |
=================================================================== |
--- chrome/browser/ui/views/location_bar/location_bar_view.h (revision 66453) |
+++ chrome/browser/ui/views/location_bar/location_bar_view.h (working copy) |
@@ -44,6 +44,7 @@ |
class SelectedKeywordView; |
class StarView; |
class SuggestedTextView; |
+class TabContentsWrapper; |
class TemplateURLModel; |
namespace views { |
@@ -72,7 +73,7 @@ |
class Delegate { |
public: |
// Should return the current tab contents. |
- virtual TabContents* GetTabContents() = 0; |
+ virtual TabContentsWrapper* GetTabContentsWrapper() = 0; |
// Returns the InstantController, or NULL if there isn't one. |
virtual InstantController* GetInstant() = 0; |
@@ -129,8 +130,8 @@ |
void SetProfile(Profile* profile); |
Profile* profile() const { return profile_; } |
- // Returns the current TabContents. |
- TabContents* GetTabContents() const; |
+ // Returns the current TabContentsWrapper. |
+ TabContentsWrapper* GetTabContentsWrapper() const; |
// Sets |preview_enabled| for the PageAction View associated with this |
// |page_action|. If |preview_enabled| is true, the view will display the |